intelmq.bots.collectors.eset package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.collectors.eset package

## Submodules

## intelmq.bots.collectors.eset.collector module

intelmq.bots.collectors.eset.collector.BOT

  alias of `intelmq.bots.collectors.eset.collector.ESETCollectorBot`

class intelmq.bots.collectors.eset.collector.ESETCollectorBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  Collect data from ESET’s TAXII API

  collection: str = '<collection>'
  endpoint: str = 'eti.eset.com'
  init()
  password: str = '<password>'
  process()
  rate_limit: int = 3600
  time_delta: int = 3600
  username: str = '<username>'

## Module contents